# Versions:
#
# X.Y.ZAB
# X - Stable major version of the application,
# Y - Minor release with additional features
# Z - Version with bug fixes
# A - Pre-release types:
#      "a" - alpha
#      "b" - betha
#      "c" - release candidate
# B - Pre-release number
#
# X,Y,Z - range <0, inf)
# B - range <1, inf)
#
# Examples:
#  1.1
#  0.3.5b1
#  0.6c3
__version__ = '0.1.0'
